#!/usr/bin/env python3

import time
import math
import random
from influxdb import InfluxDBClient

def get_sensor_value(timestamp=None):
    """
    Pretend to read value from external sensor.
    """
    if timestamp is None:
        timestamp = time.time()
    time_of_day = (timestamp % 86400) / 86400
    time_of_week = (timestamp % (86400 * 7)) / (86400 * 7)

    # Temperature
    temperature = 15 - math.sin(time_of_day * 2 * math.pi - 0.5) * 10
    temperature *= random.gauss(1, 0.01)

    # Pressure
    pressure = 1013 + 8 * math.sin(time_of_week * 2 * math.pi)
    pressure *= random.gauss(1, 0.001)

    # Brightness
    brightness = - math.cos(time_of_day * 2 * math.pi) * 1203
    if brightness < 0:
        brightness = 0
    brightness *= random.gauss(1, 0.01)

    return temperature, pressure, brightness

if __name__ == "__main__":
    client = InfluxDBClient('influxdb', 8086, database="tick-demo")
    client.create_database('tick-demo')

    while True:
        temperature, pressure, brightness = get_sensor_value()

        json_body = [
                {
                    "measurement": "weather",
                    "fields": {
                        "temperature": temperature,
                        "pressure": pressure,
                        "brightness": brightness,
                    }
                }
            ]
        try:
            client.write_points(json_body)
            print("%d Data added." % time.time())
        except Exception as e:
            print(e)

        time.sleep(10)

